@@ -6,9 +6,10 @@ use Carp;
 
 use feature ":5.10";
 
+use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -28,7 +29,8 @@ use constant {EXPANDED          => FLD_KEY_PREFIX . 'EXPANDED',
               BACKUP            => FLD_KEY_PREFIX . 'BACKUP',
              };
 
-my %Globals = ('=:' => catdir("", ""));
+my %Globals = ('=:'  => catdir("", "",),
+               '=::' => $Config{path_sep});
 
 
 # Match punctuation chars, but not the underscores.
@@ -461,7 +463,7 @@ Config::INI::RefVars - INI file reader, allows the referencing of INI and enviro
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -810,7 +812,7 @@ The hash returned by the C<variables> method is then:
    }
 
 
-=head3 Variables related to the Source:
+=head3 Variables related to the Source
 
 =over
 
@@ -827,6 +829,22 @@ only present if the source is a file, otherwise they are not defined.
 
 =back
 
+=head3 Variables related to the OS
+
+=over
+
+=item C<=:>
+
+The directory separator, C<\> on Windows, C</> on Linux.  Note: This is not
+always sufficient to create a path, e.g. on VMS.
+
+=item C<=::>
+
+Path separator, which is used in the environment variable C<PATH>, for
+example.
+
+=back
+
 
 =head3 Space Variables
 
